<?php
/*
Plugin Name:  Free IP Lookup Widget
Plugin URI:   https://www.hide-my-ip.com/ip-lookup-widget.shtml
Description:  Allows your visitors to see their IP address and location. Shortcode examples: [hidemyip option_value="sidebar"] and [hidemyip option_value="banner"]
Version:      1.2
Author:       Hide My IP
Author URI:   https://www.hide-my-ip.com
License:      GPL2
License URI:  https://www.hide-my-ip.com
Text Domain:  hidemyip-iplookup-plugin
*/


// Register style sheet.
add_action( 'wp_enqueue_scripts', 'free_ip_lookup_widget_register_plugin_styles_for_free_ip' );


/**
 * Register style sheet.
 */
function free_ip_lookup_widget_register_plugin_styles_for_free_ip() {
	wp_register_style( 'free-ip-lookup-widget', plugins_url( 'free-ip-lookup-widget.css', __FILE__ ) );
	wp_enqueue_style( 'free-ip-lookup-widget' );
}


// Register and load the widget
function free_ip_lookup_widget_wpb_load_widget() {
    register_widget( 'wpb_widget_for_free_ip' );
}
add_action( 'widgets_init', 'free_ip_lookup_widget_wpb_load_widget' );

class wpb_widget_for_free_ip extends WP_Widget {

	function __construct() {

	  // Add Widget scripts
		parent::__construct(

			// Base ID of your widget
			'wpb_widget_free_ip_lookup',

			// Widget name will appear in UI
			__('Free IP Lookup Widget', 'wpb_widget_free_ip_lookup'),

			// Widget description
			array( 'description' => __( 'Displays a widget to show IP lookup.', 'wpb_widget_free_ip_lookup' ), )
		);
	}

	public function widget( $args, $instance ) {
		$option_value = ! empty( $instance['fi_option_value'] ) ? $instance['fi_option_value'] : '';
		$ipaddress = $this->free_ip_lookup_widget_get_client_ip();
		$url = 'https://api.ipf1.com/?'.$ipaddress;
		$data = wp_remote_retrieve_body( wp_remote_get( $url ) );

		$information = explode("|", $data);
		
		$fi_city = $information[1];
		$fi_province = $information[2];
		$fi_country_code = $information[3];
		$fi_country_name = $information[4];

		$country_flag_file = plugins_url( 'images/flags/' . $fi_country_code . '.png', __FILE__ );
		
		
		
		?>
		<div class="free-ip-lookup-widget">
			<div class="fi-your-ip-address">Your IP Address</div>
			<h1 class="fi-ip-address"><?=$ipaddress?></h1>
			<div class="fi-location-container">
				<img class="fi-country-flag" src="<?=$country_flag_file?>" alt="Your IP Location: <?=$fi_city?>, <?=$fi_country_name?>" title="Your IP Location: <?=$fi_city?>, <?=$fi_country_name?>">
				<h3 class="fi-locations">
					<?php
						if($fi_city != "")
						{
							echo $fi_city;
						}

						if($fi_province != "")
						{
							if($fi_city != ""){
								echo ", ";
							}
							echo $fi_province;
						}

						if($fi_country_name != "")
						{
							if($fi_city != "" || $fi_province != ""){
								echo ", ";
							}
							echo $fi_country_name;
						}

					?>
				</h3>
			</div>
			<div class="fi-additional-links">

			</div>
		</div>
		<?php
		
	}

	private function free_ip_lookup_widget_get_client_ip() {
	    $ipaddress = '';

		if(getenv('HTTP_CLIENT_IP'))
	        $ipaddress = getenv('HTTP_CLIENT_IP');
	    else if(getenv('HTTP_X_FORWARDED_FOR'))
	        $ipaddress = getenv('HTTP_X_FORWARDED_FOR');
	    else if(getenv('HTTP_X_FORWARDED'))
	        $ipaddress = getenv('HTTP_X_FORWARDED');
	    else if(getenv('HTTP_FORWARDED_FOR'))
	        $ipaddress = getenv('HTTP_FORWARDED_FOR');
	    else if(getenv('HTTP_FORWARDED'))
	        $ipaddress = getenv('HTTP_FORWARDED');
	    else if(getenv('REMOTE_ADDR'))
	        $ipaddress = getenv('REMOTE_ADDR');
	    else
	        $ipaddress = 'UNKNOWN';
	 
	    return $ipaddress;
	}

	public function form( $instance ) {
		 $optin_value = ! empty( $instance['fi_option_value'] ) ? $instance['fi_option_value'] : '';
		?>
		<p>
			<label for=""><?php _e( 'Option:' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'fi_option_value' ); ?>" name="<?php echo $this->get_field_name( 'fi_option_value' ); ?>" type="text">
			  <option value='banner' <?php echo ($optin_value=='banner')?'selected':''; ?>>Banner View</option>
			  <option value='sidebar'  <?php echo ($optin_value=='sidebar')?'selected':''; ?>>SideBar view</option>
			</select>
		</p>
		<?php
	}

	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['fi_option_value'] = ( ! empty( $new_instance['fi_option_value'] ) ) ? $new_instance['fi_option_value']  : '';
		return $instance;
	}
}



add_shortcode( 'hidemyip', 'widget_hide_shortcode_for_free_ip' );

function widget_hide_shortcode_for_free_ip( $atts ) {

	// Configure defaults and extract the attributes into variables
	 $hide_atts = shortcode_atts(
		array(
			'option_value' => 'sidebar',
		), $atts);

	 	$option_value = ! empty( $hide_atts['option_value']) ? $hide_atts['option_value'] : '';
		$ipaddress = free_ip_lookup_widget_get_client_ip();
		$url = 'https://api.ipf1.com/?'.$ipaddress;
		$data = wp_remote_retrieve_body( wp_remote_get( $url ) );

		$information = explode("|", $data);
		
		$fi_city = $information[1];
		$fi_province = $information[2];
		$fi_country_code = $information[3];
		$fi_country_name = $information[4];
		
		if($fi_city != "")
		{
			$loc .= $fi_city;
		}

		if($fi_province != "")
		{
			if($fi_city != ""){
				$loc .= ", ";
			}
			$loc .= $fi_province;
		}

		if($fi_country_name != "")
		{
			if($fi_city != "" || $fi_province != ""){
				$loc .= ", ";
			}
			$loc .= $fi_country_name;
		}

		$country_flag_file = plugins_url( 'images/flags/' . $fi_country_code . '.png', __FILE__ );
		$str = '
		
		<div class="free-ip-lookup-widget">
			<div class="fi-your-ip-address">Your IP Address</div>
			<h1 class="fi-ip-address">'.$ipaddress.'</h1>
			<div class="fi-location-container">
				<img class="fi-country-flag" src="'.$country_flag_file.'" alt="Your IP Location: '.$loc.'" title="Your IP Location: '.$loc.'">
				<h3 class="fi-locations">';
						

				$str .= $loc;
					
				$str .= '</h3>
			</div>
			<div class="fi-additional-links">

			</div>
			
		</div>';
		
		return $str;

}


function free_ip_lookup_widget_get_client_ip() {
	$ipaddress = '';
	if(getenv('HTTP_CLIENT_IP'))
	    $ipaddress = getenv('HTTP_CLIENT_IP');
	else if(getenv('HTTP_X_FORWARDED_FOR'))
	    $ipaddress = getenv('HTTP_X_FORWARDED_FOR');
	else if(getenv('HTTP_X_FORWARDED'))
	    $ipaddress = getenv('HTTP_X_FORWARDED');
	else if(getenv('HTTP_FORWARDED_FOR'))
	    $ipaddress = getenv('HTTP_FORWARDED_FOR');
	else if(getenv('HTTP_FORWARDED'))
	    $ipaddress = getenv('HTTP_FORWARDED');
	else if(getenv('REMOTE_ADDR'))
	    $ipaddress = getenv('REMOTE_ADDR');
	else
	    $ipaddress = 'UNKNOWN';

	return $ipaddress;
}


